@@ -51,6 +51,10 @@ class CacheWriter:
         self._cache_queue.put_nowait(message)
 
     async def stop(self):
+        if self._cache_record_task is not None:
+            self._cache_record_task.cancel()
+            self._cache_record_task = None
+
         self.logger().info(f"Stopping cache writer redis connections.")
         self._redis.close()
         await self._redis.wait_closed()
